<?xml version="1.0" ?><!DOCTYPE TS><TS language="ar" version="2.1">
<context>
    <name>ExpressionBar</name>
    <message>
        <source>Expression Error</source>
        <translation>خطأ في الصيغة</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Dark theme</source>
        <translation>السمة الداكنة</translation>
    </message>
    <message>
        <source>Simple mode</source>
        <translation>النمط البسيط</translation>
    </message>
    <message>
        <source>Scientific mode</source>
        <translation>النمط العلمي</translation>
    </message>
    <message>
        <source>Deepin Calculator</source>
        <translation>حاسبة ديبين</translation>
    </message>
    <message>
        <source>Deepin Calculator is a simple and easy to use desktop calculator. It supports addition, subtraction, multiplication and division.</source>
        <translation>حاسبة ديبين: حاسبة بسيطة وسهلة لاستخدامات سطح المكتب، تدعم عمليات الجمع والطرح والضرب والقسمة.</translation>
    </message>
</context>
<context>
    <name>SimpleListDelegate</name>
    <message>
        <source>Expression Error</source>
        <translation>خطأ في الصيغة</translation>
    </message>
</context>
</TS>